==> speech-dispatcher-0.10.2-i586-3.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    rm $NEW
  fi
}

config etc/speech-dispatcher/speechd.conf.new
config etc/speech-dispatcher/clients/emacs.conf.new
config etc/speech-dispatcher/modules/flite.conf.new
config etc/speech-dispatcher/modules/kali.conf.new
config etc/speech-dispatcher/modules/ibmtts.conf.new
config etc/speech-dispatcher/modules/dtk-generic.conf.new
config etc/speech-dispatcher/modules/baratinoo.conf.new
config etc/speech-dispatcher/modules/mary-generic-disabled.conf.new
config etc/speech-dispatcher/modules/espeak-ng-mbrola-generic.conf.new
config etc/speech-dispatcher/modules/espeak-ng.conf.new
config etc/speech-dispatcher/modules/ivona.conf.new
config etc/speech-dispatcher/modules/swift-generic.conf.new
config etc/speech-dispatcher/modules/espeak.conf.new
config etc/speech-dispatcher/modules/voxin.conf.new
config etc/speech-dispatcher/modules/llia_phon-generic.conf.new
config etc/speech-dispatcher/modules/cicero.conf.new
config etc/speech-dispatcher/modules/festival.conf.new
config etc/speech-dispatcher/modules/espeak-mbrola-generic.conf.new
config etc/speech-dispatcher/modules/epos-generic.conf.new
( cd usr/lib ; rm -rf libspeechd.so )
( cd usr/lib ; ln -sf libspeechd.so.2.6.0 libspeechd.so )
( cd usr/lib ; rm -rf libspeechd.so.2 )
( cd usr/lib ; ln -sf libspeechd.so.2.6.0 libspeechd.so.2 )
( cd usr/share/speech-dispatcher/locale/es_AR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_AR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_BO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_BO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CL ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CL ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CU ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CU ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_DO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_DO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_EC ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_EC ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_GT ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_GT ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_HN ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_HN ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_NI ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_NI ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PA ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PA ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PE ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PE ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PY ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PY ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_SV ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_SV ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_UY ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_UY ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_VE ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_VE ; ln -sf ../es_419/emojis.dic emojis.dic )

==> speech-dispatcher-0.11.5-i686-3.txz: install/doinst.sh <==
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    rm $NEW
  fi
}

config etc/speech-dispatcher/speechd.conf.new
config etc/speech-dispatcher/modules/llia_phon-generic.conf.new
config etc/speech-dispatcher/modules/mimic3-generic.conf.new
config etc/speech-dispatcher/modules/espeak.conf.new
config etc/speech-dispatcher/modules/flite.conf.new
config etc/speech-dispatcher/modules/festival.conf.new
config etc/speech-dispatcher/modules/dtk-generic.conf.new
config etc/speech-dispatcher/modules/epos-generic.conf.new
config etc/speech-dispatcher/modules/espeak-ng-mbrola.conf.new
config etc/speech-dispatcher/modules/espeak-ng-mbrola-generic.conf.new
config etc/speech-dispatcher/modules/espeak-mbrola-generic.conf.new
config etc/speech-dispatcher/modules/cicero.conf.new
config etc/speech-dispatcher/modules/baratinoo.conf.new
config etc/speech-dispatcher/modules/espeak-ng.conf.new
config etc/speech-dispatcher/modules/mary-generic.conf.new
config etc/speech-dispatcher/modules/ibmtts.conf.new
config etc/speech-dispatcher/modules/kali.conf.new
config etc/speech-dispatcher/modules/voxin.conf.new
config etc/speech-dispatcher/modules/swift-generic.conf.new
config etc/speech-dispatcher/clients/emacs.conf.new
( cd usr/lib ; rm -rf libspeechd.so )
( cd usr/lib ; ln -sf libspeechd.so.2.6.0 libspeechd.so )
( cd usr/lib ; rm -rf libspeechd.so.2 )
( cd usr/lib ; ln -sf libspeechd.so.2.6.0 libspeechd.so.2 )
( cd usr/libexec/speech-dispatcher-modules ; rm -rf sd_espeak-ng-mbrola )
( cd usr/libexec/speech-dispatcher-modules ; ln -sf sd_espeak-ng sd_espeak-ng-mbrola )
( cd usr/share/speech-dispatcher/locale/es_AR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_AR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_BO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_BO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CL ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CL ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CU ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_CU ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_DO ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_DO ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_EC ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_EC ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_GT ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_GT ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_HN ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_HN ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_NI ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_NI ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PA ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PA ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PE ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PE ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PR ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PR ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PY ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_PY ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_SV ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_SV ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_UY ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_UY ; ln -sf ../es_419/emojis.dic emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_VE ; rm -rf emojis.dic )
( cd usr/share/speech-dispatcher/locale/es_VE ; ln -sf ../es_419/emojis.dic emojis.dic )
